import * as react from 'react';
import react__default, { ElementType, AllHTMLAttributes, ReactNode, InputHTMLAttributes, TextareaHTMLAttributes, ButtonHTMLAttributes, BaseHTMLAttributes } from 'react';
import { IconType } from 'react-icons';
import { TooltipContentProps } from '@radix-ui/react-tooltip';
import { IconBaseProps } from 'react-icons/lib';
import * as _tw_classed_react from '@tw-classed/react';

type Size = 'tiny' | 'small' | 'medium' | 'large';
type SizeStyleProp = Partial<Record<Size, string>>;
type State = 'error' | 'success';
type StateStyleProp = Partial<Record<State, string>>;

type HTMLProps = Omit<AllHTMLAttributes<HTMLElement>, 'as'>;
interface Props$g extends Omit<HTMLProps, 'size'> {
    as?: ElementType;
    size?: Size;
}
declare const Box: react.ForwardRefExoticComponent<Props$g & react.RefAttributes<HTMLElement>>;

type Variant$1 = 'primary' | 'secondary' | 'outlined-primary' | 'transparent' | 'black' | 'borderless';
interface Props$f extends Props$g {
    iconRight?: ReactNode;
    iconLeft?: ReactNode;
    loading?: boolean;
    variant?: Variant$1;
}
declare const Button: react.ForwardRefExoticComponent<Props$f & react.RefAttributes<HTMLButtonElement>>;

interface Props$e {
    isOpen: boolean;
    setIsOpen: (isOpen: boolean) => void;
    text: string;
    title: string;
}
/**
 * An alert component
 * Usage: Import both the `Alert` component and `useAlert` hook into your own components.
 * Hook:
 * const { openAlert, alertProps } = useAlert()
 * Render:
 * <Alert {...alertProps} />
 */
declare function Alert({ isOpen, setIsOpen, text, title }: Props$e): JSX.Element;

interface DrawerProps {
    isOpen: boolean;
    setIsOpen: (isOpen: boolean) => void;
    children: react__default.ReactNode;
    title?: string;
    description?: string;
}
/**
 * A side drawer component
 */
declare const Drawer: ({ isOpen, setIsOpen, children, title, description, }: DrawerProps) => JSX.Element;

interface Props$d {
    label?: string;
    size?: Size;
    error?: string;
    success?: string;
    required?: boolean;
    optional?: boolean;
    description?: ReactNode;
    children: ReactNode;
    append?: ReactNode;
    hidden?: boolean;
}
declare function FieldLayout(props: Props$d): JSX.Element | null;

interface Props$c extends Omit<InputHTMLAttributes<HTMLInputElement>, 'size' | 'id' | 'children'> {
    label?: string;
    size?: Size;
    success?: string;
    error?: string;
    description?: ReactNode;
    icon?: IconType;
    iconClass?: string;
    copy?: boolean;
    actions?: ReactNode;
    optional?: boolean;
}
declare const Input: react.ForwardRefExoticComponent<Props$c & react.RefAttributes<HTMLInputElement>>;

interface Props$b extends Omit<TextareaHTMLAttributes<HTMLTextAreaElement>, 'size' | 'id' | 'children'> {
    label?: string;
    size?: Size;
    success?: string;
    error?: string;
    description?: ReactNode;
}
declare const TextBox: react.ForwardRefExoticComponent<Props$b & react.RefAttributes<HTMLTextAreaElement>>;

interface Props$a extends Props$c {
    withIcon?: boolean;
    isTruncated?: boolean;
    onResolveName: (address: string) => any;
}
/**
 * Primary Input component for React Hook Form
 *
 * @param label - Label for the input
 * @param name - Name of the input
 * @param type - Type of the input
 * @returns Input component
 *
 */
declare const AddressInput: react.ForwardRefExoticComponent<Props$a & react.RefAttributes<HTMLInputElement>>;

interface Props$9 extends Omit<ButtonHTMLAttributes<HTMLButtonElement>, 'size' | 'ref' | 'children'> {
    size?: Size;
    icon: ReactNode;
    label: string;
}
declare const IconButton: react.ForwardRefExoticComponent<Props$9 & react.RefAttributes<HTMLButtonElement>>;

interface Props$8 {
    lang: any;
    code: string;
}
declare function CodeBox({ lang, code }: Props$8): JSX.Element;

interface CodeBlock {
    code: string;
    name: string;
    lang: any;
}
interface Props$7 {
    blocks: CodeBlock[];
}
declare function TabbedCodeBox({ blocks }: Props$7): JSX.Element;

interface Props$6 {
    isOpen: boolean;
    setIsOpen: (isOpen: boolean) => void;
    children?: ReactNode;
    empty?: boolean;
}
declare function Modal({ isOpen, setIsOpen, children, empty }: Props$6): JSX.Element;

type Variant = 'dark' | 'orange' | 'red' | 'yellow' | 'green' | 'blue' | 'primary' | 'default';
interface Props$5 extends Props$g {
    iconRight?: ReactNode;
    iconLeft?: ReactNode;
    variant?: Variant;
}
declare function Badge(props: Props$5): JSX.Element;

interface Props$4 extends Pick<TooltipContentProps, 'side' | 'sideOffset'> {
    tip: ReactNode;
    children: ReactNode;
    label?: string;
    delay?: number;
    theme?: 'dark' | 'clear';
}
declare function Tooltip({ children, tip, label, side, sideOffset, theme, }: Props$4): JSX.Element;

interface Props$3 extends IconBaseProps {
    size?: Size | number;
    icon: IconType;
}
declare function Icon({ className, size, icon, ...rest }: Props$3): JSX.Element;

interface Option {
    label: string;
    value: string | number;
    append?: React.ReactNode;
    prepend?: React.ReactNode;
    disabled?: boolean;
}
interface SelectProps<T> {
    label?: string;
    description?: ReactNode;
    tooltip?: ReactNode;
    options: Option[];
    size?: Size;
    onChange?: (value: string | number, isCustom?: boolean) => void;
    defaultValue?: T;
    customOption?: boolean;
    disabled?: boolean;
    loading?: boolean;
}
declare const Select: <T extends unknown>({ options, onChange, label, tooltip, description, size, defaultValue, customOption, disabled: fieldDisabled, loading, }: SelectProps<T>) => JSX.Element;

interface CollapseProps {
    isOpen: boolean;
    setIsOpen: (open: boolean) => void;
    content: React.ReactNode;
    children: React.ReactNode;
    disabled?: boolean;
}
declare const Collapse: ({ children, content, disabled, }: CollapseProps) => JSX.Element;

interface ToggleSwitchProps {
    enabled: boolean;
    setEnabled: (enabled: boolean) => void;
    title?: string;
    description?: ReactNode;
    onChange?: (enabled: boolean) => void;
    disabled?: boolean;
    size?: Size;
}
declare const ToggleSwitch: ({ title, description, enabled, setEnabled, onChange, disabled, size, }: ToggleSwitchProps) => JSX.Element;

interface Props$2 {
    id: string;
    recipient: string;
    title: string;
    iconURL: string;
    location?: string;
    time?: string;
    date?: string;
    lockAddress: string;
    network: number;
    QRCodeURL: string;
    email?: string;
}
declare function Ticket({ iconURL, title, recipient, id, QRCodeURL, date, time, location, lockAddress, network, email, }: Props$2): JSX.Element;
interface TicketLabelProps {
    label: string;
    value: string;
}
declare function TicketLabel({ label, value }: TicketLabelProps): JSX.Element;
interface TicketItemProps {
    icon: ReactNode;
    value: string;
}
declare function TicketItem({ icon, value }: TicketItemProps): JSX.Element;

interface DisclosureProps {
    label: string;
    description?: ReactNode;
    children?: ReactNode;
    isLoading?: boolean;
    disabled?: boolean;
    defaultOpen?: boolean;
}
declare const Disclosure: ({ label, description, children, isLoading, disabled, defaultOpen, }: DisclosureProps) => JSX.Element;

interface NavbarMenuProps {
    title: string;
    options: {
        title: string;
        url: string;
    }[];
}
interface NavbarImageProps {
    title: string;
    src: string;
    url: string;
    alt?: string;
    description?: string;
}
interface NavLinkProps {
    title: string;
    url: string;
    description?: string;
}
interface NavEmbedProps {
    title: string;
    embed: string;
}
type NavOptionProps = NavbarMenuProps | NavbarImageProps | NavLinkProps | NavEmbedProps;
type MenuSectionProps = {
    title: string;
    small?: boolean;
    options: NavOptionProps[];
} | {
    title: string;
    small?: boolean;
    url: string;
};
type ActionsProps$1 = {
    title: string;
    url: string;
    icon?: IconType;
} | {
    content: ReactNode;
};
interface NavbarProps {
    menuSections: MenuSectionProps[];
    actions: ActionsProps$1[];
    logo: {
        url: string;
        src?: string;
        size?: number;
        domain?: string;
    };
    extraClass?: {
        mobile?: string;
        desktop?: string;
    };
    showSocialIcons?: boolean;
}
declare const HeaderNav: ({ menuSections, actions, logo, extraClass, showSocialIcons, }: NavbarProps) => JSX.Element;

interface EmailSubscriptionFormProps {
    onSubmit: (email: string) => void;
    title: string;
    description?: string;
}

interface FooterItem {
    label: ReactNode;
    url: string;
    target?: HTMLAnchorElement['target'];
}
interface MenuItemsProps {
    title: string;
    options: FooterItem[];
}
type ActionsProps = {
    label: string;
    url: string;
} | {
    label: string;
    onClick: () => void;
};
interface FooterProps {
    logo: {
        url: string;
        src?: string;
    };
    actions?: ActionsProps[];
    privacyUrl?: string;
    termsUrl?: string;
    menuSections: MenuItemsProps[];
    subscriptionForm?: EmailSubscriptionFormProps;
}
declare const Footer: ({ privacyUrl, termsUrl, menuSections, subscriptionForm, logo, actions, }: FooterProps) => JSX.Element;

declare const Placeholder: {
    Line: _tw_classed_react.ClassedComponentType<"div", Partial<{
        size: "sm" | "md" | "lg" | "xl";
        width: "sm" | "md" | "lg" | "xl" | "full";
    }>, Pick<{
        variants: {
            size: {
                sm: string;
                md: string;
                lg: string;
                xl: string;
            };
            width: {
                sm: string;
                md: string;
                lg: string;
                xl: string;
                full: string;
            };
        };
        defaultVariants: {
            size: "md";
            width: "full";
        };
    }, "variants" | "defaultVariants" | "dataAttributes">>;
    Image: _tw_classed_react.ClassedComponentType<"div", Partial<{
        size: "sm" | "md" | "lg" | "xl";
        rounded: "none" | "sm" | "md" | "lg" | "full";
    }>, Pick<{
        variants: {
            size: {
                sm: string;
                md: string;
                lg: string;
                xl: string;
            };
            rounded: {
                none: string;
                sm: string;
                md: string;
                lg: string;
                full: string;
            };
        };
        defaultVariants: {
            size: "md";
            rounded: "md";
        };
    }, "variants" | "defaultVariants" | "dataAttributes">>;
    Root: _tw_classed_react.ClassedComponentType<"div", Partial<{
        spaced: "sm" | "md" | "lg" | "xl";
        inline: boolean | "true" | "false";
    }>, Pick<{
        variants: {
            spaced: {
                sm: string;
                md: string;
                lg: string;
                xl: string;
            };
            inline: {
                false: string;
            };
        };
        defaultVariants: {
            spaced: "md";
            inline: boolean;
        };
    }, "variants" | "defaultVariants" | "dataAttributes">>;
    Card: _tw_classed_react.ClassedComponentType<"div", Partial<{
        size: "sm" | "md" | "lg" | "xl";
    }>, Pick<{
        variants: {
            size: {
                sm: string;
                md: string;
                lg: string;
                xl: string;
            };
        };
        defaultVariants: {
            size: "sm";
        };
    }, "variants" | "defaultVariants" | "dataAttributes">>;
};

interface Props$1 extends Omit<ButtonHTMLAttributes<HTMLButtonElement>, 'size' | 'ref' | 'children' | 'value' | 'onChange'> {
    value: boolean;
    disabled?: boolean;
    onChange: (value: boolean) => void;
    size?: Extract<Size, 'small' | 'medium'>;
}
declare const Toggle: ({ onChange, value, disabled, size, ...rest }: Props$1) => JSX.Element;

interface DetailProps extends Pick<BaseHTMLAttributes<HTMLDivElement>, 'className'> {
    label: React.ReactNode;
    children?: React.ReactNode;
    loading?: boolean;
    inline?: boolean;
    labelSize?: Size;
    valueSize?: Size;
    truncate?: boolean;
    tooltip?: boolean;
    justify?: boolean;
}
declare const Detail: ({ label, children, labelSize, valueSize, loading, inline, truncate, tooltip, justify, className, }: DetailProps) => JSX.Element;

interface CertificateProps {
    name: string;
    description: ReactNode;
    owner: string;
    lockAddress: string;
    network: number;
    networkName?: string;
    expiration?: string;
    issuer: string;
    image: string;
    issueDate?: string;
    tokenId?: string | number;
    badge?: ReactNode;
    transactionsHash?: ReactNode;
    externalUrl?: string;
    isMobile?: boolean;
}
declare const Certificate: ({ badge, name, description, owner, issueDate, network, expiration, tokenId, issuer, lockAddress, transactionsHash, externalUrl, image, networkName, isMobile, }: CertificateProps) => JSX.Element;

declare const CardBase: _tw_classed_react.ClassedComponentType<"div", Partial<{
    variant: "primary" | "secondary" | "transparent" | "simple" | "danger";
    padding: "sm" | "md" | "xs";
    shadow: "sm" | "lg";
}>, Pick<{
    variants: {
        variant: {
            simple: string;
            primary: string;
            secondary: string;
            danger: string;
            transparent: string;
        };
        padding: {
            xs: string;
            sm: string;
            md: string;
        };
        shadow: {
            sm: string;
            lg: string;
        };
    };
    defaultVariants: {
        variant: "primary";
        padding: "sm";
    };
}, "variants" | "defaultVariants" | "dataAttributes">>;
type CardBaseProps = React.ComponentProps<typeof CardBase> & {
    icon?: React.ReactNode;
    as?: keyof JSX.IntrinsicElements;
};
declare const Card: {
    ({ variant, shadow, padding, children, className, as, }: CardBaseProps): JSX.Element;
    Title: _tw_classed_react.ClassedComponentType<"span", {}, {}>;
    Description: _tw_classed_react.ClassedComponentType<"span", {}, {}>;
    Label: ({ title, description }: CardLabelProps) => JSX.Element;
};
interface CardLabelProps {
    title: string;
    description?: string;
}

interface TabProps {
    title: ReactNode;
    description?: ReactNode;
    children: ReactNode;
    disabled?: boolean;
    onNext?: () => Promise<any> | void;
    onNextLabel?: string;
    showButton?: boolean;
    button?: Props$f;
    loading?: boolean;
}
interface TabsProps {
    defaultTab?: number;
    tabs?: TabProps[];
    onTabChange?: (tab: number) => void;
}
declare function Tabs({ defaultTab, onTabChange, tabs }: TabsProps): JSX.Element;

declare const ImageUploadWrapper: _tw_classed_react.ClassedComponentType<"div", Partial<{
    size: "sm" | "full";
}>, Pick<{
    variants: {
        size: {
            sm: string;
            full: string;
        };
    };
    defaultVariants: {
        size: "sm";
    };
}, "variants" | "defaultVariants" | "dataAttributes">>;
declare const ImageContainer: _tw_classed_react.ClassedComponentType<"div", Partial<{
    imageRatio: "cover" | "box";
}>, Pick<{
    variants: {
        imageRatio: {
            cover: string;
            box: string;
        };
    };
    defaultVariants: {
        imageRatio: "box";
    };
}, "variants" | "defaultVariants" | "dataAttributes">>;
type ImageUploadWrapperProps = React.ComponentProps<typeof ImageUploadWrapper> & React.ComponentProps<typeof ImageContainer> & {
    preview: string;
    isUploading?: boolean;
    onChange: (fileOrFileUrl: File[] | string) => Promise<unknown> | unknown;
    description?: string;
};
declare const ImageUpload: ({ onChange, preview, isUploading, description, size, imageRatio, className, }: ImageUploadWrapperProps) => JSX.Element;

declare const minifyAddress: (address: string) => string;
declare const isAddressOrEns: (address?: string) => boolean;
declare const unlockEmailSubscription: (email: string) => Promise<void>;

type Link = any;
interface Props {
    children: ReactNode;
    Link?: Link | null;
}
interface UIProviderContext {
    Link?: Link | null;
}
declare const UnlockUIContext: react.Context<UIProviderContext>;
declare function UnlockUIProvider({ children, Link }: Props): JSX.Element;
declare const useUnlockUI: () => UIProviderContext;

declare const Images: {
    Attention: react.FunctionComponent<react.SVGProps<SVGSVGElement> & {
        title?: string | undefined;
    }>;
    CoinbaseWallet: react.FunctionComponent<react.SVGProps<SVGSVGElement> & {
        title?: string | undefined;
    }>;
    Frame: react.FunctionComponent<react.SVGProps<SVGSVGElement> & {
        title?: string | undefined;
    }>;
    Metamask: react.FunctionComponent<react.SVGProps<SVGSVGElement> & {
        title?: string | undefined;
    }>;
    Status: react.FunctionComponent<react.SVGProps<SVGSVGElement> & {
        title?: string | undefined;
    }>;
    Unlock: react.FunctionComponent<react.SVGProps<SVGSVGElement> & {
        title?: string | undefined;
    }>;
    UnlockMonogram: react.FunctionComponent<react.SVGProps<SVGSVGElement> & {
        title?: string | undefined;
    }>;
    UnlockWordMark: react.FunctionComponent<react.SVGProps<SVGSVGElement> & {
        title?: string | undefined;
    }>;
    WalletConnect: react.FunctionComponent<react.SVGProps<SVGSVGElement> & {
        title?: string | undefined;
    }>;
};

declare const GuidesHeader: () => JSX.Element;
declare const GuidesFooter: () => JSX.Element;

declare const ShowcaseHeader: () => JSX.Element;
declare const ShowcaseFooter: () => JSX.Element;

export { AddressInput, Alert, Badge, Box, Button, Card, Certificate, CodeBox, Collapse, Detail, Disclosure, Drawer, FieldLayout, Footer, GuidesFooter, GuidesHeader, HeaderNav, Icon, IconButton, ImageUpload, Images, Input, Modal, Placeholder, Select, ShowcaseFooter, ShowcaseHeader, Size, SizeStyleProp, State, StateStyleProp, TabbedCodeBox, Tabs, TextBox, Ticket, TicketItem, TicketLabel, Toggle, ToggleSwitch, Tooltip, UnlockUIContext, UnlockUIProvider, isAddressOrEns, minifyAddress, unlockEmailSubscription, useUnlockUI };
